/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: WinPos.h,v 1.5 2009/07/11 13:57:28 bowkenken Exp $
***************************************************************/

#ifndef WIN_POS_H
#define WIN_POS_H

////////////////////////////////////////////////////////////////
// ɥκɸȥδ
////////////////////////////////////////////////////////////////

#include "win-kind.h"

#ifdef D_WS
#endif //D_WS

#ifdef D_GTK
#include "gtk/gtk.h"
#endif //D_GTK

#ifdef D_MFC
#endif //D_MFC

class WinPos {

private:
	bool flagDraw;
	long mX, mY, mW, mH;

public:
	WinPos();
	~WinPos();

	void *getWin( win_kind_t kind );

	void set(
		win_kind_t kind,
		long *px, long *py,
		long *pw, long *ph );
	void get(
		win_kind_t kind,
		long *px, long *py,
		long *pw, long *ph );

	void calc( win_kind_t kind );

	void draw( win_kind_t kind, bool flagDlg = false );
	void wipe( win_kind_t kind, bool flagDlg = false );
};

#endif // WIN_POS_H
